@@ -505,6 +505,8 @@ class Base_Page(Borg, unittest.TestCase):
             self.driver.switch_to.frame(self.driver.find_elements_by_tag_name("iframe")[index])
         elif frame_id is not None:  # add by myself
             self.driver.switch_to.frame(frame_id)
+        else:
+            raise Exception("All arguments are None in switch_1st_layer_frame()")
 
     def switch_under_frame(self, name=None, index=None, frame_id=None, element=None, wait_time=0.5):
         """switch to iframe, add support for frame id, iframe element
@@ -519,6 +521,8 @@ class Base_Page(Borg, unittest.TestCase):
             self.driver.switch_to.frame(frame_id)
         elif element is not None:
             self.driver.switch_to.frame(element)
+        else:
+            raise Exception("All arguments are None in switch_under_frame()")
 
     # COMMENT THIS FUNCTION BECAUSE ERROR CAN'T FIX BUT STILL WORKING
     # def _get_locator(key):
